@@ -20,7 +20,7 @@ use Config::IniFiles;
 
 use vars qw($VERSION);
 
-$VERSION = '0.36';
+$VERSION = '0.38';
 
 use constant DATABASE_FILE => 'cpansmoke.dat';
 use constant CONFIG_FILE   => 'cpansmoke.ini';
@@ -59,12 +59,12 @@ my %throw_away;
 
     return 1 if $TiedObj;
 
-    my $filename = catfile( CPANPLUS::Internals::Utils->_home_dir(), '.cpanplus', DATABASE_FILE );
+    my $filename = catfile( $conf->get_conf('base'), DATABASE_FILE );
     msg(qq{Loading YACSmoke database "$filename"});
     $TiedObj = tie( %Checked, 'SDBM_File', $filename, O_CREAT|O_RDWR, 0644 )
 	or error(qq{Failed to open "$filename": $!});
 
-    my $config_file = catfile( CPANPLUS::Internals::Utils->_home_dir(), '.cpanplus', CONFIG_FILE );
+    my $config_file = catfile( $conf->get_conf('base'), '.cpanplus', CONFIG_FILE );
     if ( -r $config_file ) {
        my $cfg = Config::IniFiles->new(-file => $config_file);
        my @list = $cfg->val( 'CONFIG', 'exclude_dists' );
